[GRASS-SVN] r65575 - in grass/trunk: doc gui/wxpython/docs gui/wxpython/gui_core gui/wxpython/lmgr gui/wxpython/rlisetup gui/wxpython/vdigit gui/wxpython/web_services imagery/i.atcorr imagery/i.segment include/iostream lib/ogsf lib/python/gunittest lib/python/pygrass lib/python/pygrass/raster lib/python/pygrass/vector lib/vector/Vlib locale/po mswindows raster/r.distance raster/r.li/r.li.daemon raster/r.neighbors raster/r.null raster/r.relief raster3d/r3.flow temporal/t.rast.accdetect temporal/t.rast.contour temporal/t.rast.to.vect

svn_grass at osgeo.org svn_grass at osgeo.org
Sat Jul 11 07:01:46 PDT 2015


Author: neteler
Date: 2015-07-11 07:01:46 -0700 (Sat, 11 Jul 2015)
New Revision: 65575

Modified:
   grass/trunk/doc/parms_flags.txt
   grass/trunk/gui/wxpython/docs/wxGUI.nviz.html
   grass/trunk/gui/wxpython/gui_core/vselect.py
   grass/trunk/gui/wxpython/lmgr/frame.py
   grass/trunk/gui/wxpython/rlisetup/wizard.py
   grass/trunk/gui/wxpython/vdigit/g.gui.vdigit.html
   grass/trunk/gui/wxpython/web_services/widgets.py
   grass/trunk/imagery/i.atcorr/6s.cpp
   grass/trunk/imagery/i.segment/create_isegs.c
   grass/trunk/include/iostream/empq_impl.h
   grass/trunk/lib/ogsf/gs2.c
   grass/trunk/lib/python/gunittest/case.py
   grass/trunk/lib/python/gunittest/reporters.py
   grass/trunk/lib/python/pygrass/raster/category.py
   grass/trunk/lib/python/pygrass/utils.py
   grass/trunk/lib/python/pygrass/vector/geometry.py
   grass/trunk/lib/vector/Vlib/net_build.c
   grass/trunk/locale/po/grassmods_pt.po
   grass/trunk/locale/po/grasswxpy_cs.po
   grass/trunk/locale/po/grasswxpy_de.po
   grass/trunk/locale/po/grasswxpy_el.po
   grass/trunk/locale/po/grasswxpy_es.po
   grass/trunk/locale/po/grasswxpy_fr.po
   grass/trunk/locale/po/grasswxpy_id.po
   grass/trunk/locale/po/grasswxpy_it.po
   grass/trunk/locale/po/grasswxpy_ja.po
   grass/trunk/locale/po/grasswxpy_ko.po
   grass/trunk/locale/po/grasswxpy_lv.po
   grass/trunk/locale/po/grasswxpy_ml.po
   grass/trunk/locale/po/grasswxpy_pl.po
   grass/trunk/locale/po/grasswxpy_pt.po
   grass/trunk/locale/po/grasswxpy_pt_br.po
   grass/trunk/locale/po/grasswxpy_ro.po
   grass/trunk/locale/po/grasswxpy_ru.po
   grass/trunk/locale/po/grasswxpy_th.po
   grass/trunk/locale/po/grasswxpy_tr.po
   grass/trunk/locale/po/grasswxpy_vi.po
   grass/trunk/locale/po/grasswxpy_zh.po
   grass/trunk/mswindows/GRASS-Installer.nsi.tmpl
   grass/trunk/raster/r.distance/defs.h
   grass/trunk/raster/r.li/r.li.daemon/daemon.h
   grass/trunk/raster/r.neighbors/r.neighbors.html
   grass/trunk/raster/r.null/r.null.html
   grass/trunk/raster/r.relief/r.relief.html
   grass/trunk/raster3d/r3.flow/r3.flow.html
   grass/trunk/temporal/t.rast.accdetect/t.rast.accdetect.html
   grass/trunk/temporal/t.rast.contour/t.rast.contour.html
   grass/trunk/temporal/t.rast.to.vect/t.rast.to.vect.html
Log:
various typo fixes, found by the Debian lintian QA tool

Modified: grass/trunk/doc/parms_flags.txt
===================================================================
--- grass/trunk/doc/parms_flags.txt	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/doc/parms_flags.txt	2015-07-11 14:01:46 UTC (rev 65575)
@@ -64,7 +64,7 @@
 Export:
 *  input=name file=name for all raster, sites and vector modules
 *  export modules should *all* have an output= parameter, however they
-   should allow to specify "-" to write to stdout (for unix piping)
+   should allow specifying "-" to write to stdout (for unix piping)
 
 -> file is external file. Should be read from current directory, not
    within mapset!

Modified: grass/trunk/gui/wxpython/docs/wxGUI.nviz.html
===================================================================
--- grass/trunk/gui/wxpython/docs/wxGUI.nviz.html	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/gui/wxpython/docs/wxGUI.nviz.html	2015-07-11 14:01:46 UTC (rev 65575)
@@ -296,7 +296,7 @@
 
 <h4>Cutting planes</h4>
 
-Cutting planes allow to cut surfaces along a plane. You can switch 
+Cutting planes allow cutting surfaces along a plane. You can switch 
 between six planes; to disable cutting planes switch to <em>None</em>.
 Initially the plane is vertical, you can change it to horizontal by
 setting <em>tilt</em> 90 degrees. The <em>X</em> and <em>Y</em> values

Modified: grass/trunk/gui/wxpython/gui_core/vselect.py
===================================================================
--- grass/trunk/gui/wxpython/gui_core/vselect.py	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/gui/wxpython/gui_core/vselect.py	2015-07-11 14:01:46 UTC (rev 65575)
@@ -2,7 +2,7 @@
 @package gui_core.vselect
 
 @brief wxGUI classes for interactive selection of vector
-features. Allows to create a new vector map from selected vector
+features. Allows creating a new vector map from selected vector
 features or return their categories
 
 Classes:
@@ -81,8 +81,8 @@
 class VectorSelectBase():
     """@brief Main class of vector selection function
 
-    It allows to select vector features from map display and to export
-    them as a new vector map. Current version allows to select
+    It allows selecting vector features from map display and to export
+    them as a new vector map. Current version allows selecting
     features one-by-one by single click in map display.
 
     This class can be initialized with (see CreateDialog()) or without
@@ -327,7 +327,7 @@
         
     """
     def SetSelectedCat(self, cats):
-        # allows to set selected vector categories by list of cats (per line)
+        # allows setting selected vector categories by list of cats (per line)
         info = self.QuerySelectedMap()
         if 'Category' not in info:
             return

Modified: grass/trunk/gui/wxpython/lmgr/frame.py
===================================================================
--- grass/trunk/gui/wxpython/lmgr/frame.py	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/gui/wxpython/lmgr/frame.py	2015-07-11 14:01:46 UTC (rev 65575)
@@ -1015,7 +1015,7 @@
             # can be relaxed in future
             # but keep it strict unless needed otherwise
             raise ValueError("OnChangeCWD cmd parameter must be list of"
-                             " lenght 1 or 2 and 'cd' as a first item")
+                             " length 1 or 2 and 'cd' as a first item")
         if cmd and len(cmd) > 2:
             # this might be a user error
             write_beginning(command=cmd)

Modified: grass/trunk/gui/wxpython/rlisetup/wizard.py
===================================================================
--- grass/trunk/gui/wxpython/rlisetup/wizard.py	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/gui/wxpython/rlisetup/wizard.py	2015-07-11 14:01:46 UTC (rev 65575)
@@ -671,9 +671,9 @@
         self.sizer.Add(item=self.RowUpLefttxt, border=5, pos=(2, 2),
                        flag=wx.ALIGN_LEFT | wx.ALIGN_CENTER_VERTICAL | wx.ALL)
 
-        #row lenght
+        #row length
         self.RowLenlabel = wx.StaticText(parent=self, id=wx.ID_ANY,
-                                         label=_('Row lenght of sampling frame'))
+                                         label=_('Row length of sampling frame'))
 
         self.RowLentxt = wx.TextCtrl(parent=self, id=wx.ID_ANY, size=(250, -1))
         wx.CallAfter(self.RowLenlabel.SetFocus)
@@ -683,9 +683,9 @@
         self.sizer.Add(item=self.RowLentxt, border=5, pos=(3, 2),
                        flag=wx.ALIGN_LEFT | wx.ALIGN_CENTER_VERTICAL | wx.ALL)
 
-        #column lenght
+        #column length
         self.ColLenlabel = wx.StaticText(parent=self, id=wx.ID_ANY,
-                                         label=_('Row lenght of sampling frame'))
+                                         label=_('Row length of sampling frame'))
 
         self.ColLentxt = wx.TextCtrl(parent=self, id=wx.ID_ANY, size=(250, -1))
         wx.CallAfter(self.ColLenlabel.SetFocus)

Modified: grass/trunk/gui/wxpython/vdigit/g.gui.vdigit.html
===================================================================
--- grass/trunk/gui/wxpython/vdigit/g.gui.vdigit.html	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/gui/wxpython/vdigit/g.gui.vdigit.html	2015-07-11 14:01:46 UTC (rev 65575)
@@ -43,7 +43,7 @@
 selecting "New vector map" in "Select vector map"
 combobox. A new vector map is created, added to the current layer tree
 in Layer Manager and opened for editing. "Select vector map"
-combobox in the digitizer toolbar also allows to easily switch between
+combobox in the digitizer toolbar also allows easily switching between
 vector maps to be edited.
 
 <h3>EDITING AN EXISTING VECTOR MAP</h3>

Modified: grass/trunk/gui/wxpython/web_services/widgets.py
===================================================================
--- grass/trunk/gui/wxpython/web_services/widgets.py	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/gui/wxpython/web_services/widgets.py	2015-07-11 14:01:46 UTC (rev 65575)
@@ -964,7 +964,7 @@
         return sel_layers_dict
 
     def OnListSelChanging(self, event):
-        """Do not allow to select items, which cannot be requested from server.
+        """Do not allow selecting items, which cannot be requested from server.
         """
         def _emitSelected(layer):
             title = layer.GetLayerData('title')

Modified: grass/trunk/imagery/i.atcorr/6s.cpp
===================================================================
--- grass/trunk/imagery/i.atcorr/6s.cpp	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/imagery/i.atcorr/6s.cpp	2015-07-11 14:01:46 UTC (rev 65575)
@@ -75,7 +75,7 @@
     iwave = IWave::Parse();
    
     /**********************************************************************c
-	c here, we first compute an equivalent wavelenght which is the input   c
+	c here, we first compute an equivalent wavelength which is the input   c
 	c value for monochromatic conditions or the integrated value for a     c
 	c filter function (call equivwl) then, the atmospheric properties are  c
 	c computed for that wavelength (call discom then call specinterp)      c

Modified: grass/trunk/imagery/i.segment/create_isegs.c
===================================================================
--- grass/trunk/imagery/i.segment/create_isegs.c	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/imagery/i.segment/create_isegs.c	2015-07-11 14:01:46 UTC (rev 65575)
@@ -945,7 +945,7 @@
      Wb is the weigh given to band B
      SigmaB is the std dev of the object for band b
      Ws is a user-defined weight giving the importance of compactedness vs smoothness
-     PL is the perimeter lenght of the object
+     PL is the perimeter length of the object
      Npx the number of pixels within the object
      Pbbox the perimeter of the bounding box of the object.
      */

Modified: grass/trunk/include/iostream/empq_impl.h
===================================================================
--- grass/trunk/include/iostream/empq_impl.h	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/include/iostream/empq_impl.h	2015-07-11 14:01:46 UTC (rev 65575)
@@ -556,7 +556,7 @@
 //return the total nb of elements in the structure 
 template<class T, class Key>
 unsigned long em_pqueue<T,Key>::size() {
-  //sum up the lenghts(nb of elements) of the external buffers 
+  //sum up the lengths(nb of elements) of the external buffers 
   unsigned long elen = 0;
   for (unsigned short i=0; i < crt_buf; i++) {
     elen += buff[i]->get_buf_len();
@@ -1538,7 +1538,7 @@
 //************************************************************/
 template<class T, class Key>
 void em_pqueue<T,Key>::print_size() {
-  //sum up the lenghts(nb of elements) of the external buffers 
+  //sum up the lengths(nb of elements) of the external buffers 
   long elen = 0;
   cout << "EMPQ: pq=" << pq->size() <<",B0=" << buff_0->get_buf_len() << endl;
   cout.flush();

Modified: grass/trunk/lib/ogsf/gs2.c
===================================================================
--- grass/trunk/lib/ogsf/gs2.c	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/lib/ogsf/gs2.c	2015-07-11 14:01:46 UTC (rev 65575)
@@ -1711,7 +1711,7 @@
 	tbuff = gs_get_att_typbuff(gs, att, 1);
 
 	/* TODO: Provide mechanism for loading certain attributes at
-	   specified sizes, allow to scale or cap, or scale non-zero */
+	   specified sizes, allow scaling or capping, or scale non-zero */
 	if (ATT_MASK == att) {
 	    atty = ATTY_MASK;
 	}
@@ -3343,7 +3343,7 @@
 /*!
    \brief Init viewpoint
 
-   \todo allow to set center?
+   \todo allow setting center?
  */
 void GS_init_view(void)
 {

Modified: grass/trunk/lib/python/gunittest/case.py
===================================================================
--- grass/trunk/lib/python/gunittest/case.py	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/lib/python/gunittest/case.py	2015-07-11 14:01:46 UTC (rev 65575)
@@ -1170,7 +1170,7 @@
         if isinstance(module, Module):
             raise ValueError('module can be only string if other'
                              ' parameters are given')
-            # allow to pass all parameters in one dictionary called parameters
+            # allow passing all parameters in one dictionary called parameters
         if kwargs.keys() == ['parameters']:
             kwargs = kwargs['parameters']
         module = SimpleModule(module, **kwargs)

Modified: grass/trunk/lib/python/gunittest/reporters.py
===================================================================
--- grass/trunk/lib/python/gunittest/reporters.py	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/lib/python/gunittest/reporters.py	2015-07-11 14:01:46 UTC (rev 65575)
@@ -760,7 +760,7 @@
 
 
 # TODO: document info: additional information to be stored type: dict
-# allows to overwrite what was collected
+# allows overwriting what was collected
 class GrassTestFilesKeyValueReporter(GrassTestFilesCountingReporter):
 
     def __init__(self, info=None):

Modified: grass/trunk/lib/python/pygrass/raster/category.py
===================================================================
--- grass/trunk/lib/python/pygrass/raster/category.py	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/lib/python/pygrass/raster/category.py	2015-07-11 14:01:46 UTC (rev 65575)
@@ -311,7 +311,7 @@
                 elif len(cat) == 3:
                     label, min_cat, max_cat = cat
                 else:
-                    raise TypeError("Row lenght is greater than 3")
+                    raise TypeError("Row length is greater than 3")
                 #import pdb; pdb.set_trace()
                 self.append((label, min_cat, max_cat))
 

Modified: grass/trunk/lib/python/pygrass/utils.py
===================================================================
--- grass/trunk/lib/python/pygrass/utils.py	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/lib/python/pygrass/utils.py	2015-07-11 14:01:46 UTC (rev 65575)
@@ -302,7 +302,7 @@
         sys.path.append(path)
 
 
-def split_in_chunk(iterable, lenght=10):
+def split_in_chunk(iterable, length=10):
     """Split a list in chunk.
 
     >>> for chunk in split_in_chunk(range(25)): print chunk
@@ -322,7 +322,7 @@
     """
     it = iter(iterable)
     while True:
-        chunk = tuple(itertools.islice(it, lenght))
+        chunk = tuple(itertools.islice(it, length))
         if not chunk:
             return
         yield chunk

Modified: grass/trunk/lib/python/pygrass/vector/geometry.py
===================================================================
--- grass/trunk/lib/vector/Vlib/net_build.c	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/lib/vector/Vlib/net_build.c	2015-07-11 14:01:46 UTC (rev 65575)
@@ -22,7 +22,7 @@
    \brief Build network graph with turntable.
 
    Internal format for edge costs is integer, costs are multiplied
-   before conversion to int by 1000 and for lenghts LL without geo flag by 1000000.
+   before conversion to int by 1000 and for lengths LL without geo flag by 1000000.
    The same multiplication factor is used for nodes.
    Costs in database column may be 'integer' or 'double precision' number >= 0
    or -1 for infinity i.e. arc or node is closed and cannot be traversed
@@ -672,7 +672,7 @@
    \brief Build network graph.
 
    Internal format for edge costs is integer, costs are multiplied
-   before conversion to int by 1000 and for lenghts LL without geo flag by 1000000.
+   before conversion to int by 1000 and for lengths LL without geo flag by 1000000.
    The same multiplication factor is used for nodes.
    Costs in database column may be 'integer' or 'double precision' number >= 0
    or -1 for infinity i.e. arc or node is closed and cannot be traversed

Modified: grass/trunk/locale/po/grassmods_pt.po
===================================================================
--- grass/trunk/locale/po/grassmods_pt.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grassmods_pt.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -38540,7 +38540,7 @@
 #, fuzzy
 msgid "For coor valid point/centroid, for length valid line/boundary"
 msgstr ""
-"Tipo dos elementos (coor para ponto/centróide válido, lenght para linha/"
+"Tipo dos elementos (coor para ponto/centróide válido, length para linha/"
 "contorno válido)"
 
 #: ../vector/v.to.db/parse.c:54

Modified: grass/trunk/locale/po/grasswxpy_cs.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_cs.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_cs.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -16795,7 +16795,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:751

Modified: grass/trunk/locale/po/grasswxpy_de.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_de.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_de.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -3927,7 +3927,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_el.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_el.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_el.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -3894,7 +3894,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_es.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_es.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_es.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -4118,7 +4118,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_fr.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_fr.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_fr.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -3830,7 +3830,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr "Nombre de lignes du cadre d'échantillonage"
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_id.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_id.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_id.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -4196,7 +4196,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_it.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_it.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_it.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -3805,7 +3805,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_ja.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_ja.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_ja.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -4082,7 +4082,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_ko.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_ko.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_ko.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -3792,7 +3792,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_lv.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_lv.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_lv.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -16519,7 +16519,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:751

Modified: grass/trunk/locale/po/grasswxpy_ml.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_ml.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_ml.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -4005,7 +4005,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_pl.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_pl.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_pl.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -3990,7 +3990,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_pt.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_pt.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_pt.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -4191,7 +4191,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_pt_br.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_pt_br.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_pt_br.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -4325,7 +4325,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_ro.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_ro.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_ro.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -4071,7 +4071,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_ru.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_ru.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_ru.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -4165,7 +4165,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_th.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_th.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_th.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -4003,7 +4003,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_tr.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_tr.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_tr.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -4157,7 +4157,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_vi.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_vi.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_vi.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -4151,7 +4151,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr ""
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/locale/po/grasswxpy_zh.po
===================================================================
--- grass/trunk/locale/po/grasswxpy_zh.po	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/locale/po/grasswxpy_zh.po	2015-07-11 14:01:46 UTC (rev 65575)
@@ -3998,7 +3998,7 @@
 
 #: ../gui/wxpython/rlisetup/wizard.py:676
 #: ../gui/wxpython/rlisetup/wizard.py:688
-msgid "Row lenght of sampling frame"
+msgid "Row length of sampling frame"
 msgstr "取样框架行长度"
 
 #: ../gui/wxpython/rlisetup/wizard.py:802

Modified: grass/trunk/mswindows/GRASS-Installer.nsi.tmpl
===================================================================
--- grass/trunk/mswindows/GRASS-Installer.nsi.tmpl	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/mswindows/GRASS-Installer.nsi.tmpl	2015-07-11 14:01:46 UTC (rev 65575)
@@ -317,8 +317,8 @@
 
 ;Function CheckInstDir
 ;	Var /GLOBAL INSTDIR_TEST
-;	Var /GLOBAL INSTDIR_LENGHT	
-;	Var /GLOBAL INSTDIR_TEST_LENGHT
+;	Var /GLOBAL INSTDIR_LENGTH	
+;	Var /GLOBAL INSTDIR_TEST_LENGTH
 ;	Var /GLOBAL MESSAGE_CHKINST_
 ;	
 ;	StrCpy $MESSAGE_CHKINST_ "WARNING: you are about to install GRASS into a directory that has spaces$\r$\n"
@@ -330,10 +330,10 @@
 ;	
 ;	${StrReplace} "$INSTDIR_TEST" " " "" "$INSTDIR"
 ;	
-;	StrLen $INSTDIR_LENGHT "$INSTDIR"
-;	StrLen $INSTDIR_TEST_LENGHT "$INSTDIR_TEST"
+;	StrLen $INSTDIR_LENGTH "$INSTDIR"
+;	StrLen $INSTDIR_TEST_LENGTH "$INSTDIR_TEST"
 ;	
-;	${If} $INSTDIR_TEST_LENGHT < $INSTDIR_LENGHT	
+;	${If} $INSTDIR_TEST_LENGTH < $INSTDIR_LENGTH	
 ;		MessageBox MB_OK|MB_ICONEXCLAMATION "$MESSAGE_CHKINST_"
 ;	${EndIf}
 ;	

Modified: grass/trunk/raster/r.distance/defs.h
===================================================================
--- grass/trunk/raster/r.distance/defs.h	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/raster/r.distance/defs.h	2015-07-11 14:01:46 UTC (rev 65575)
@@ -30,7 +30,7 @@
 	CELL cat;		/* category number */
 	int *row, *col;		/* arrays of pixels indexes */
 	int ncells;		/* count of edges cells with this cat */
-	int nalloc;		/* lenght of allocation for row,col */
+	int nalloc;		/* length of allocation for row,col */
     } *catlist;			/* array of cat:edgelists */
     int ncats;			/* number of cats */
     int nalloc;			/* length of allocation for catlist */

Modified: grass/trunk/raster/r.li/r.li.daemon/daemon.h
===================================================================
--- grass/trunk/raster/r.li/r.li.daemon/daemon.h	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/raster/r.li/r.li.daemon/daemon.h	2015-07-11 14:01:46 UTC (rev 65575)
@@ -223,8 +223,8 @@
   * \brief adapts the mask at current raster file
   * \param mask name of mask raster file
   * \param raster the name of current raster file
-  * \param rl the lenght in rows of sample area
-  * \param cl the lenght in cols of sample area
+  * \param rl the length in rows of sample area
+  * \param cl the length in cols of sample area
   * \return the name of mask raster file to use
   */
 char *mask_preprocessing(char *mask, char *raster, struct area_entry *ad);

Modified: grass/trunk/raster/r.neighbors/r.neighbors.html
===================================================================
--- grass/trunk/raster/r.neighbors/r.neighbors.html	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/raster/r.neighbors/r.neighbors.html	2015-07-11 14:01:46 UTC (rev 65575)
@@ -159,7 +159,7 @@
 <em>Neighborhood Size:</em>
 The neighborhood <b>size</b> specifies which cells surrounding any given
 cell fall into the neighborhood for that cell.
-The <b>size</b> must be an odd integer and represent the lenght of one of
+The <b>size</b> must be an odd integer and represent the length of one of
 moving window edges in cells.
 For example, a size value of 3 will result in
 <div class="code"><pre>

Modified: grass/trunk/raster/r.null/r.null.html
===================================================================
--- grass/trunk/raster/r.null/r.null.html	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/raster/r.null/r.null.html	2015-07-11 14:01:46 UTC (rev 65575)
@@ -36,7 +36,7 @@
 <p><em>r.null</em> and reclassified maps:<br>
 The problem is, if r.null was run on the reclass raster it would alter the
 original and any other reclass rasters of the original.  Therefore r.null 
-doesn't allow to recode reclassified maps (products of r.reclass).
+doesn't allow recoding reclassified maps (products of r.reclass).
 <br>
 So, the way to recode such a map is: The user makes a raster out of the
 reclass that isn't a reclass by copying it:<br>

Modified: grass/trunk/raster/r.relief/r.relief.html
===================================================================
--- grass/trunk/raster/r.relief/r.relief.html	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/raster/r.relief/r.relief.html	2015-07-11 14:01:46 UTC (rev 65575)
@@ -85,7 +85,7 @@
 
 <h3>Exporting shaded relief maps to GeoTIFF</h3>
 
-The data range of shaded relief maps usually does not permit to export the
+The data range of shaded relief maps usually does not permit exporting the
 map to GeoTIFF format along with its associated color table due to limitations
 in the GeoTIFF format.
 <p>

Modified: grass/trunk/raster3d/r3.flow/r3.flow.html
===================================================================
--- grass/trunk/raster3d/r3.flow/r3.flow.html	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/raster3d/r3.flow/r3.flow.html	2015-07-11 14:01:46 UTC (rev 65575)
@@ -33,7 +33,7 @@
 and each category (record) represents one segment of a flowline, so that attributes
 specific for segments can be written. In case of <b>vector_field</b> input, only velocity is written,
 in case of <b>input</b> option, also values of the input 3D raster are written.
-Option <b>sampled</b> allows to sample (query) given 3D raster by flow lines (computed from different 3D raster) and
+Option <b>sampled</b> allows sampling (query) given 3D raster by flow lines (computed from different 3D raster) and
 write the values of the given 3D raster as attributes of the flow line segments.
 Note that using <b>a</b> flag results in longer computation time, so consider increasing
 <b>step</b> and <b>max_error</b> parameter.

Modified: grass/trunk/temporal/t.rast.accdetect/t.rast.accdetect.html
===================================================================
--- grass/trunk/temporal/t.rast.accdetect/t.rast.accdetect.html	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/temporal/t.rast.accdetect/t.rast.accdetect.html	2015-07-11 14:01:46 UTC (rev 65575)
@@ -24,7 +24,7 @@
 process can be set, either by using space time raster datasets or 
 by using fixed values for all raster cells and time steps. 
 <p>
-Using space time raster datasets allow to specify minimum and maximum 
+Using space time raster datasets allow specifying minimum and maximum 
 values for each raster cell and each time step. For example, we want to 
 detect the germination (minimum value) and harvesting (maximum value) 
 dates for different crops in Germany using the growing-degree-day (GDD) 

Modified: grass/trunk/temporal/t.rast.contour/t.rast.contour.html
===================================================================
--- grass/trunk/temporal/t.rast.contour/t.rast.contour.html	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/temporal/t.rast.contour/t.rast.contour.html	2015-07-11 14:01:46 UTC (rev 65575)
@@ -19,7 +19,7 @@
 flag, that avoids the creation of attribute tables. 
 The parallel creation of attribute tables is not supported.
 <p>
-The <em>where</em> option allows to select subsets of the input space time raster
+The <em>where</em> option allows selecting subsets of the input space time raster
 dataset.
 <p>
 The flag <em>-n</em> can be used to force the registration of empty 

Modified: grass/trunk/temporal/t.rast.to.vect/t.rast.to.vect.html
===================================================================
--- grass/trunk/temporal/t.rast.to.vect/t.rast.to.vect.html	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/temporal/t.rast.to.vect/t.rast.to.vect.html	2015-07-11 14:01:46 UTC (rev 65575)
@@ -19,7 +19,7 @@
 flag, that avoids the creation of attribute tables. 
 The parallel creation of attribute tables is not supported.
 <p>
-The <em>where</em> option allows to select subsets of the input space time raster
+The <em>where</em> option allows selecting subsets of the input space time raster
 dataset.
 <p>
 The flag <em>-n</em> can be used to force the registration of empty 



More information about the grass-commit mailing list
--- grass/trunk/lib/python/pygrass/vector/geometry.py	2015-07-11 13:00:17 UTC (rev 65574)
+++ grass/trunk/lib/python/pygrass/vector/geometry.py	2015-07-11 14:01:46 UTC (rev 65575)
@@ -617,7 +617,7 @@
             >>> line.get_pnt(5)      #doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
             Traceback (most recent call last):
                 ...
             ValueError: The distance exceed the lenght of the line,
             that is: 1.414214
             >>> line.get_pnt(1)
             Point(0.707107, 0.707107)
@@ -627,7 +627,7 @@
         # instantiate an empty Point object
         maxdist = self.length()
         if distance > maxdist:
-            str_err = "The distance exceed the lenght of the line, that is: %f"
+            str_err = "The distance exceed the length of the line, that is: %f"
             raise ValueError(str_err % maxdist)
         pnt = Point(0, 0, -9999)
         if not libvect.Vect_point_on_line(self.c_points, distance,
@@ -617,7 +617,7 @@
             Traceback (most recent call last):
                 ...
-            ValueError: The distance exceed the lenght of the line,
+            ValueError: The distance exceed the length of the line,
             that is: 1.414214
             >>> line.get_pnt(1)

Modified: grass/trunk/lib/vector/Vlib/net_build.c
===================================================================